@@ -18,6 +18,7 @@ commands_ = [
 
     ('findpath', 'mgetool.cli.findpath'),
     ('makebatch', 'mgetool.cli.makebatch'),
+    ('cpdir', 'mgetool.cli.cpdir'),
 
 ]
 
@@ -83,7 +84,7 @@ def main(prog='mgetool', description='mgetool command line tool.', args=None):
         except KeyboardInterrupt:
             pass
         except CLIError as x:
-            parser.error(x)
+            parser.error(str(x))
         except Exception as x:
             if args.traceback:
                 raise
@@ -92,4 +93,3 @@ def main(prog='mgetool', description='mgetool command line tool.', args=None):
                 l2 = ('To get a full traceback, use: {} -T {} ...'
                       .format(prog, args.command))
                 parser.error(l1 + l2)
-
