@@ -133,12 +133,16 @@ class BatchPathMatch:
         if dirs is None:
             dirs = self.file_dir
 
-        dirs = [i for i in dirs if i not in (".", "./")]
-        dirs_text = "\n".join(dirs)
-        index = [dirs_text.count(i) - 1 for i in dirs]
-        dirs = [dirs[n] for n, i in enumerate(index) if i == 0]
+        par_disk = [i.parent for i in dirs]
 
-        return dirs
+        par_disk = set(par_disk)
+
+        res = set(dirs) - par_disk
+
+        res = list(res)
+        res.sort()
+
+        return res
 
     def dir_relpath(self, path=None):
         """Get the real-path to input path."""
@@ -533,17 +537,22 @@ class BatchFileMatch:
                 self._rm_check += 1
 
     def get_leaf_dir(self, dirs=None):
-        """Get the leaf dirs. Remove "." path."""
+        """Get the leaf dirs."""
 
         # The ../paths could be wrong!
 
         if dirs is None:
             dirs = self.file_dir
 
-        dirs = [i for i in dirs if i not in (".", "./")]
-        dirs_text = "\n".join(dirs)
-        index = [dirs_text.count(i) - 1 for i in dirs]
-        dirs = [dirs[n] for n, i in enumerate(index) if i == 0]
+        par_disk = [i.parent for i in dirs]
+
+        par_disk = set(par_disk)
+
+        res = set(dirs) - par_disk
+
+        res = list(res)
+        res.sort()
+
         return dirs
 
 # if __name__=="__main__":
